@@ -487,43 +487,66 @@ module Rouge
 
       state :root do
         # comments
-        rule /;.*$/, Comment::Single
-        rule /\s+/m, Text
+        rule %r/;.*$/, Comment::Single
+        rule %r/#!.*/, Comment::Single
+        rule %r/#\|/, Comment::Multiline, :block_comment
+        rule %r/#;/, Comment::Multiline, :sexp_comment
+        rule %r/\s+/m, Text
 
-        rule /[+-]inf[.][f0]/, Num::Float
-        rule /[+-]nan[.]0/, Num::Float
-        rule /[-]min[.]0/, Num::Float
-        rule /[+]max[.]0/, Num::Float
+        rule %r/[+-]inf[.][f0]/, Num::Float
+        rule %r/[+-]nan[.]0/, Num::Float
+        rule %r/[-]min[.]0/, Num::Float
+        rule %r/[+]max[.]0/, Num::Float
 
-        rule /-?\d+\.\d+/, Num::Float
-        rule /-?\d+/, Num::Integer
+        rule %r/-?\d+\.\d+/, Num::Float
+        rule %r/-?\d+/, Num::Integer
 
-        rule /#:#{id}+/, Name::Tag  # keyword
+        rule %r/#:#{id}+/, Name::Tag  # keyword
 
-        rule /#b[01]+/, Num::Bin
-        rule /#o[0-7]+/, Num::Oct
-        rule /#d[0-9]+/, Num::Integer
-        rule /#x[0-9a-f]+/i, Num::Hex
-        rule /#[ei][\d.]+/, Num::Other
+        rule %r/#b[01]+/, Num::Bin
+        rule %r/#o[0-7]+/, Num::Oct
+        rule %r/#d[0-9]+/, Num::Integer
+        rule %r/#x[0-9a-f]+/i, Num::Hex
+        rule %r/#[ei][\d.]+/, Num::Other
 
-        rule /"(\\\\|\\"|[^"])*"/, Str
-        rule /['`]#{id}/i, Str::Symbol
-        rule /#\\([()\/'"._!\$%& ?=+-]{1}|[a-z0-9]+)/i,
+        rule %r/"(\\\\|\\"|[^"])*"/, Str
+        rule %r/['`]#{id}/i, Str::Symbol
+        rule %r/#\\([()\/'"._!\$%& ?=+-]{1}|[a-z0-9]+)/i,
           Str::Char
-        rule /#t|#f/, Name::Constant
-        rule /(?:'|#|`|,@|,|\.)/, Operator
+        rule %r/#t(rue)?|#f(alse)?/i, Name::Constant
+        rule %r/(?:'|#|`|,@|,|\.)/, Operator
 
-        rule /(['#])(\s*)(\()/m do
+        rule %r/(['#])(\s*)(\()/m do
           groups Str::Symbol, Text, Punctuation
         end
 
         # () [] {} are all permitted as like pairs
-        rule /\(|\[|\{/, Punctuation, :command
-        rule /\)|\]|\}/, Punctuation
+        rule %r/\(|\[|\{/, Punctuation, :command
+        rule %r/\)|\]|\}/, Punctuation
 
         rule id, Name::Variable
       end
 
+      state :block_comment do
+        rule %r/[^|#]+/, Comment::Multiline
+        rule %r/\|#/, Comment::Multiline, :pop!
+        rule %r/#\|/, Comment::Multiline, :block_comment
+        rule %r/[|#]/, Comment::Multiline
+      end
+
+      state :sexp_comment do
+        rule %r/[({\[]/, Comment::Multiline, :sexp_comment_inner
+        rule %r/"(?:\\"|[^"])*?"/, Comment::Multiline, :pop!
+        rule %r/[^\s]+/, Comment::Multiline, :pop!
+        rule(//) { pop! }
+      end
+
+      state :sexp_comment_inner do
+        rule %r/[^(){}\[\]]+/, Comment::Multiline
+        rule %r/[)}\]]/, Comment::Multiline, :pop!
+        rule %r/[({\[]/, Comment::Multiline, :sexp_comment_inner
+      end
+
       state :command do
         rule id, Name::Function do |m|
           if self.class.keywords.include? m[0]
